"""Built in actions for Jaseci"""
from fastapi import HTTPException
from jaseci.actions.live_actions import jaseci_action
import metadata_parser


@jaseci_action()
def get_page_meta(url: str = ""):
    """
    Util to parse metadata out of urls and html documents
    """

    if url == "":
        raise HTTPException(status_code=400, detail=str("No url provided"))

    try:
        page = metadata_parser.MetadataParser(
            url=url,
            url_headers={
                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:94.0) Gecko/20100101 Firefox/94.0",
            },
        )
        return page.metadata
    except Exception as e:
        raise HTTPException(status_code=500, detail=str(e))



from jaseci.utils.test_core import CoreTest, jac_testcase


class WebtoolTest(CoreTest):
    """UnitTest for Webtool"""

    fixture_src = __file__

    @jac_testcase("webtool.jac", "get_meta_valid")
    def test_get_meta_valid(self, ret):
        self.assertTrue(ret["success"])
        self.assertTrue("og" in ret["report"][0])
        self.assertTrue("meta" in ret["report"][0])
        self.assertTrue("dc" in ret["report"][0])
        self.assertTrue("page" in ret["report"][0])

    @jac_testcase("webtool.jac", "get_meta_403_response")
    def test_get_meta_403_response(self, ret):
        self.assertTrue(ret["success"])
        self.assertTrue("og" in ret["report"][0])
        self.assertTrue("meta" in ret["report"][0])
        self.assertTrue("dc" in ret["report"][0])
        self.assertTrue("page" in ret["report"][0])

    @jac_testcase("webtool.jac", "get_meta_invalid")
    def test_get_meta_invalid(self, ret):
        self.assertFalse(ret["success"])
